#
# spec file for package eksctl
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

Name:           eksctl
Version:        0.203.0
Release:        1.1
Summary:        The official CLI for Amazon EKS
License:        Apache-2.0
URL:            https://github.com/eksctl-io/eksctl
Source:         eksctl-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  go >= 1.21.5
BuildRequires:  zsh

%description
eksctl is a simple CLI tool for creating clusters on EKS - Amazon's new managed
Kubernetes service for EC2. It is written in Go, and uses CloudFormation.

You can create a cluster in minutes with just one command – eksctl create
cluster!

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p1 -a 1

%build
COMMIT_HASH="$(sed -n 's/commit: \(.*\)/\1/p' %_sourcedir/%{name}.obsinfo)"

DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X github.com/weaveworks/eksctl/pkg/version.gitCommit=${COMMIT_HASH} \
   -X github.com/weaveworks/eksctl/pkg/version.buildDate=$BUILD_DATE" \
   -o bin/eksctl ./cmd/eksctl

%install
# Install the binary.
install -D -m 0755 bin/%{name} "%{buildroot}/%{_bindir}/%{name}"

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{name}

%check
%{buildroot}/%{_bindir}/%{name} version | grep %{version}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{name}

%changelog
* Fri Feb  7 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.203.0:
  * Add release notes for v0.203.0 (#8154)
  * Resolve clusterDNS for IPv6 MNG AL2023 with custom AMI (#8170)
  * [Hybrid Nodes] Make `remoteNetworkConfig.IAM.Provider` field
    case insensitive (#8169)
  * [Hybrid Nodes] Remove strict requirement of providing a VGW or
    TGW during cluster creation (#8168)
  * Bump golang.org/x/crypto from v0.22.0 to v0.32.0 (#8166)
  * Prepare for next development iteration (#8159)
* Thu Jan 23 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.202.0:
  * Revert dependencies changes that are making release workflow
    fail (#8157)
  * Add release notes for v0.202.0 (#8142)
  * Adding support for us-isof and eu-isoe regions (#8151)
  * Bump github.com/gofrs/flock from 0.8.1 to 0.12.1 (#8024)
  * Bump github.com/github-release/github-release from 0.10.0 to
    0.10.1 (#8107)
  * Migrate `goformation` under `pkg/` as a local package and
    remove location re-write (#8153)
  * Upgrade to go 1.22 (#8125)
  * Wait for vpccni to become active before updating it to use IRSA
    (#8152)
  * Remove `xtables.lock` which should be managed by the VPC CNI
    (#8134)
  * Use `DescribeClusterVersions` API instead of hardcoding EKS
    version data (#8144)
  * Fix e2e integration tests (#8149)
  * Update import path of local goformation fork, fixing `go mod
    verify` (#8148)
  * Disable metrics-server default addon creation for unsupported
    regions (#8146)
  * Enable default addon creation for auto mode clusters (#8140)
  * Remove SSM install script from AL2; SSM is pre-installed on EKS
    AL based AMIs (#8135)
  * Prepare for next development iteration (#8143)
* Wed Jan 15 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.201.0:
  * Add release notes for v0.201.0 (#8115)
  * Fix E2E tests (#8139)
  * Update nvidia-device-plugin to v0.17.0 (#7918)
  * Update aws-node to v1.19.2 (#7899)
  * Update coredns (#7901)
  * Bump github.com/Masterminds/semver/v3 from 3.2.1 to 3.3.1
    (#8047)
  * Bump github.com/aws/aws-sdk-go-v2/config from 1.27.11 to 1.28.9
    (#8131)
  * Bump
    github.com/aws/aws-sdk-go-v2/service/elasticloadbalancingv2
    from 1.43.3 to 1.43.4 (#8129)
  * Bump github.com/aws/aws-sdk-go-v2/service/cloudformation from
    1.56.3 to 1.56.4 (#8127)
  * Bump
    github.com/aws/aws-sdk-go-v2/service/cognitoidentityprovider
    from 1.36.3 to 1.48.4 (#8130)
  * Bump github.com/aws/aws-sdk-go-v2/service/elasticloadbalancing
    from 1.28.8 to 1.28.9 (#8132)
  * Bump github.com/aws/aws-sdk-go-v2/service/outposts from 1.48.0
    to 1.48.1 (#8133)
  * Remove EFA installation scripts; EFA is installed by default on
    EKS AL2 GPU, EKS Al2023 NVIDIA, and EKS AL2023 Neuron AMIs
    (#8113)
  * Ubuntu 24.04 support (#8094)
  * chore: Add diff created by running `make build` (#8121)
  * Bump docker/build-push-action from 5.3.0 to 6.11.0 (#8124)
  * Bump goreleaser/goreleaser-action from 5.0.0 to 6.1.0 (#8055)
  * Bump actions/setup-python from 5.1.0 to 5.3.0 (#8022)
  * Bump actions/checkout from 4.1.2 to 4.2.2 (#8021)
  * Bump docker/metadata-action from 5.5.1 to 5.6.1
  * Bump actions/setup-go from 5.0.0 to 5.2.0
  * Bump peter-evans/create-pull-request from 6.0.2 to 7.0.6
  * Bump actions/cache from 4.0.2 to 4.2.0
  * Update doc dependencies and supported Python runtime to publish
    latest doc updates (#8119)
  * Repair AL2023 with IPv6 node creation (#8120)
  * Support create cluster default addon metrics-server
  * Prepare for next development iteration (#8116)
  * support mx-central-1 region
* Thu Jan  9 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.200.0:
  * Add release notes for v0.200.0 (#8093)
  * Support for Bangkok region (`ap-southeast-7`) (#8114)
  * Update excluded contributors from release notes (#8092)
  * Prepare for next development iteration (#8088)
* Tue Dec 17 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.199.0:
  * Add release notes for v0.199.0 (#8079)
  * Support EKS managed nodegroup node repair config (#8087)
  * Add support for C8g and R8g instance types (#8041)
  * Allow importing subnets with IPv6 only (#8086)
  * EKS Auto Mode should not require setting default addons or OIDC
    (#8082)
  * Migrate dependent goformation module to a local fork (#8081)
  * Add support for `overrideBootstrapCommand` in AL2023 (#8078)
  * Prepare for next development iteration (#8080)
* Tue Dec 10 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.198.0:
  * Add release notes for v0.198.0 (#8077)
  * Add support for `preBootstrapCommands` in AL2023 (#8031)
  * Prepare for next development iteration
* Tue Dec  3 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.197.0:
  * Add release notes for v0.197.0
  * Cleanup Hybrid Nodes docs (#8072)
  * Add IAM capability if a custom IAM role is provided for Auto
    Mode
  * add link to markdown and note for hybrid nodes
  * add readme note for auto mode
  * Prepare for next development iteration
* Mon Dec  2 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.196.0:
  * Add release notes for v0.196.0
  * userdocs: fix comment for custom managed nodegroup
  * Reword IRSA warning message
  * Fix deepcopy diff
  * Prepare for next development iteration
* Mon Dec  2 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.195.0:
  * Add release notes for v0.195.0
  * Add support for EKS Hybrid Nodes (#8062)
  * Fix tests, regenerate mocks
  * Bump aws-sdk-go-v2 version and correct cluster types
  * Update goformation
  * Attach Auto Mode policies to cluster role when enabling Auto
    Mode
  * Rename AutonomousMode to AutoMode
  * Remove unused mocks
  * Support for Autonomous Mode
  * Remove deletion of aws-efs-csi-driver
  * Fix addons integration test
  * Update docs
  * Prepare for next development iteration
* Wed Oct 23 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.194.0:
  * Add release notes for v0.194.0
  * Fix tests
  * Support EKS zonal shift config
  * Fix missing ELB listener attribute actions required for AWS
    Load Balancer Controller v2.9.0
  * Prepare for next development iteration
* Fri Oct 18 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.193.0:
  * Add release notes for v0.193.0
  * Correct version drift in cluster-upgrade.md
  * Add support for M8g instance types
  * Prepare for next development iteration (#7997)
* Sat Oct 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.192.0:
  * Add release notes for v0.192.0 (#7974)
  * Add support for EKS accelerated AMIs based on AL2023 (#7996)
  * Disallow `overrideBootstrapCommand` and `preBootstrapCommands`
    for MNG AL2023 (#7990)
  * efa-installer: remove archive in 2023 files
  * cleanup efa installer archive before install
  * Prepare for next development iteration
* Fri Sep 27 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.191.0:
  * Add release notes for v0.191.0 (#7965)
  * Add support for EKS 1.31 (#7973)
  * Prepare for next development iteration
  * Prepare for next development iteration
* Sat Sep 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.190.0:
  * Add release notes for v0.190.0
  * Bump jinja2 from 3.1.3 to 3.1.4 in /userdocs
  * Bump github.com/docker/docker
  * Prepare for next development iteration
* Mon Aug 19 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.189.0:
  * Add release notes for v0.189.0
  * Skip creating OIDC manager for Outposts clusters
  * fix: resolve segfault in validateBareCluster
  * Fix SSM unit tests
  * Prepare for next development iteration (#7917)
* Thu Aug  1 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.188.0:
  * Add release notes for v0.188.0 (#7889)
  * Bump github.com/docker/docker from 24.0.9+incompatible to
    26.1.4+incompatible (#7909)
  * Update nvidia-device-plugin to v0.16.0 (#7900)
  * Add support for Kuala Lumpur region (ap-southeast-5) (#7910)
  * Add GH workflow for automatically updating nvidia device plugin
    static manifest (#7898)
  * Prepare for next development iteration (#7890)
* Tue Jul 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.187.0:
  * Add release notes for v0.187.0 (#7885)
  * Restrict `VPC.SecurityGroup` egress rules validations to
    self-managed nodes (#7883)
  * Prepare for next development iteration
* Sat Jul 13 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.186.0:
  * Add release notes for v0.186.0
  * Allow limiting the number of nodegroups created in parallel
  * Retry throttling errors, disable retry rate-limiting
  * Refactor: move bare cluster validation to
    NewCreateClusterLoader
  * Prepare for next development iteration
* Wed Jul 10 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.185.0:
  * Add release notes for v0.185.0
  * Avoid creating subnets in disallowed Availability Zone IDs
  * Add auto-ssm ami resolution for ubuntu
  * add additional hpc7g instance types
  * update efa-device-plugin.yaml to one that workkks
  * add support for hpc7g arm images
  * fix run as root efa device plugin bug
  * fixed iam permissions for karpenter
  * Prepare for next development iteration
* Thu Jul  4 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.184.0:
  * Add release notes for v0.184.0
  * Fix CRUD test
  * Fix tests
  * Reorder addons task
  * Fix integration tests
  * Add documentation
  * Fix addon integration tests
  * Fix running kube-proxy on AL2023 nodes
  * Do not restart VPC CNI DaemonSet pods
  * Honour the wait field when creating addons
  * Do not patch VPC CNI ServiceAccount to use IRSA if
    disableDefaultAddons is set
  * Add integration tests and unit tests
  * Install default addons as EKS managed addons
  * Allow cluster creation without default networking addons
  * Fix SDK paginator mocks
  * use string in logging instead of wrapping error
  * Schedule pods on a nodegroup on which no concurrent actions are
    executed (#7834)
  * Stop using P2 instances which will be retired (#7826)
  * Prepare for next development iteration
* Tue Jun 11 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.183.0:
  * Add release notes for v0.183.0
  * Fix tests
  * Make EKS 1.30 the default
  * Prepare for next development iteration
* Fri Jun  7 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.182.0:
  * Add release notes for v0.182.0
  * coredns script should exclude preview versions
  * update aws-node to latest version
  * fix typo for iam policy
  * Fix upgrading AL2 ARM64 nodegroups
  * Update pkg/addons/assets/efa-device-plugin.yaml
  * Update pkg/addons/assets/efa-device-plugin.yaml
  * Subnets availability validation should use AZs resolved by
    `EC2::DescribeSubnets` call (#7816)
  * G6 support
  * apply same formatting fix for addons.md file
  * Fix formatting for notes in documentation
  * Prepare for next development iteration
* Tue Jun  4 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.181.0:
  * Add release notes for v0.181.0
  * Disallow IRSA config if addon has existing pod identity
    associations
  * Update link to docs
  * use service level endpoint resolver instead of global endpoint
    resolver which was deprecated
  * Update AWS SDK
  * Rename fields to addonsConfig.autoApplyPodIdentityAssociations
    and addon.useDefaultPodIdentityAssociations
  * Add more validation
  * Allow updating addons with recommended IAM policies, disallow
    setting tags and wellKnownPolicies
  * fix addons integration test
  * tech debt - unskip tests from PI suite
  * update list of minimum IAM permissions
  * update unit tests
  * add auto-create-pod-identity-associations CLI flag
  * update describe addon config command to return pod identity
    config
  * add integration tests for creating and deleting addons &&
    bugfixes around validations and error checking
  * Add integration test for addon.podIdentityAssociations
  * Delete old IRSA stack in `update addon`
  * add docs && tweak validation
  * Migrate: ignore pod identity associations that already exist
  * add unit tests and update generated files
  * Migrate EKS addons to pod identity using the Addons API
  * add validations
  * take into account that not all EKS addons will support pod IDs
    at launch
  * Delete IAM resources when addon.podIdentityAssociations is []
  * Fix `create cluster` when iam.podIdentityAssociations is unset
  * Show ownerARN in `get podidentityassociations`
  * Disallow deletion of addon pod identities in `delete
    podidentityassociation`
  * Fix deleting the specified addon instead of all addons
  * Update mocks
  * Show pod identities in `get addons`, use a pointer for
    addon.podIdentityAssociations
  * Disallow updating podidentityassociations owned by addons
  * Show addon.podIdentityAssociations in `get addon`
  * Support updating podIdentityAssociations for addons
  * small tweaks
  * ammend delete addon command to delete roles for pod identity
    associations
  * add new addon fields required for pod identity support
  * Prepare for next development iteration (#7791)
* Thu May 30 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.180.0:
  * Add release notes for v0.180.0 (#7782)
  * [Pod Identity Associations] Don't allow
    `--create-service-account` flag when `--config-file` is set
    (#7789)
  * Update json schema (#7788)
  * Add option to create service account for pod identities which
    defaults to `false` (#7784)
  * Prepare for next development iteration
* Fri May 24 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.179.0:
  * Add release notes for v0.179.0
  * Support EKS 1.30
  * Prepare for next development iteration
* Thu May 23 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.178.0:
  * Add release notes for 0.178
  * Fix kubeletExtraConfig support for AL2023
  * Update aws-node from 1.12.6 to 1.18.1 (#7756)
  * Prepare for next development iteration
* Sat May 18 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.177.0:
  * update release notes for 0.177.0
  * Add release notes for v0.177.0
  * Fix deleting clusters with a non-active status
  * Fix deleting pod identities
  * Fix creating pod identities
  * Revert "[Release drafter] Treat RCs as full releases when
    drafting notes" (#7725)
  * Add utils command to migrate `iamidentitymappings` to EKS
    access entries (#7710)
  * include pre-releases as full releases when drafting release
    notes
  * Disable IMDSv1 in unowned integration tests
  * Add support for Ubuntu Pro 22.04 based EKS images (#7711)
  * Handle K8s service account lifecycle on `eksctl create/delete
    podidentityassociation` commands (#7706)
  * Allow nodegroup creation after a cluster subnet is deleted
    (#7714)
  * Fix cluster deletion in tests
  * Add integration tests
  * Add note about deleting nodegroups
  * Fix reusing instanceRoleARN for nodegroups authorized with
    access entries
  * Fix arn build logic to support different aws partitions
  * Bump dependencies
  * Update build image tag
  * Bump dependencies
  * Prepare for next development iteration
* Thu Apr 25 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.176.0:
  * Add release notes for v0.176.0 (#7672)
  * Enforce `authenticationMode:CONFIG_MAP` on Outposts (#7699)
  * [EKSCTL create cluster command] Authorise self-managed nodes
    via `aws-auth configmap` when EKS access entries are disabled
    (#7698)
  * Add support for AMIs based on AmazonLinux2023 (#7684)
  * Bump mkdocs version (#7696)
  * Display full draft release notes in PR description (#7686)
  * Allow GPU instance types for Windows nodes (#7681)
  * Include MixedInstancesPolicy LaunchTemplate for validation
  * Aim for namespace uniqueness across parallel specs (#7680)
* Mon Apr 22 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- add completion subpackages
- change upstream to new URL https://github.com/eksctl-io/eksctl
- remove ldflags to not strip the binary
* Sat Mar 23 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.175.0:
  * Add release notes for v0.175.0 (#7669)
  * Test Bottlerocket node upgrade and verify version
  * Upgrade with explicit version if release version is up-to-date
  * Prepare for next development iteration
* Sat Mar 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.174.0:
  * Fix typo in publish-release.yaml
  * Add release notes for v0.174.0
  * Rename release workflows
  * Inline script files in publish release workflows
  * Replace make build-all with goreleaser action
  * Remove goreleaser from build deps
  * Fix EFA network interface device index assignment
  * Update dependabot version updates frequency
  * Bump peter-evans/create-pull-request to fix error in GH API
  * Prepare for next development iteration
* Sat Mar 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.173.0:
  * Add release notes for v0.173.0
  * Use eksctl-bot token for release draft PR (#7629)
  * Remove dependabot from contributors
  * Fix caching credentials with assummed role MFA session
  * Add profile flag support for get and delete access entry
  * Bump github.com/cloudflare/circl from 1.3.3 to 1.3.7 (#7591)
  * Update docs with Ubuntu 20.04 supported in EKS <= 1.29 (#7618)
  * Remove inline ELB and CloudWatch policies from Cluster Role
    (#7603)
  * Automate PR with release notes draft
  * Make EKS 1.29 default
  * Update dependencies
  * Fix generate-internal-groups.sh permission
  * Bump dependencies for Dependabot alerts
  * Prepare for next development iteration
* Sat Feb 24 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.172.0:
  * Remove slackToken
  * Remove unused slack token
  * Add integ test without build target
  * Revert misdeleted checkout step for publishing release
  * Add release notes for 0.172.0
  * Revert removing RetryMetricsHeader in presigned requests
  * Update build image go version to 1.21
  * Update build image manifest, tag file and workflows
  * Update actions dependencies
  * Replace all deprecated sets.String with generic sets.Set
  * Bump k8s dependencies to v0.29
  * Update go dependencies
  * Update schema for new AMI family
  * Update userdocs dependencies
  * Bump actions/cache from 3.3.2 to 4.0.0
  * Disable slack notifications
  * Extract common steps setting up build environment from
    workflows
  * Fix checks for updated addon versions
  * Changed the error to more understandable when the region code
    isn't set
  * Prepare for next development iteration
* Sat Feb 10 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.171.0:
  * Add release notes for 0.171.0
  * Add support for Ubuntu 22.04 based EKS images
  * Announce eksctl Support Status Update
  * Improve userdocs layout
  * Prepare for next development iteration
* Sat Feb  3 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.170.0:
  * Add release notes for 0.170.0
  * Update access entries userdocs
  * Add support for Access Entry Type
  * Update release drafter template
  * Update userdocs on nodegroups
  * Fix deleting cluster sometimes drain managed nodegroups
  * docs(fargate): eksctl update command is deprecated
  * Update stale.yml
  * Expand Karpenter settings.aws block to settings for v0.33.0 and
    greater
  * Update arm-support.md
  * Prepare for next development iteration
* Fri Jan 26 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.169.0:
  * Add release notes for 0.169.0
  * Add support for EKS 1.29
  * Fix coredns pdb preventing cluster deletion
  * Fix StringLike condition key for ebsCSIController IAM policy
  * Fix outdated links
  * Handle unordered public endpoint CIDRs from EKS in endpoint
    updates
  * Prepare for next development iteration
* Sat Jan 20 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.168.0:
  * Add release notes for 0.168.0
  * Fix generating presigned URL for K8s authentication
  * Safely access/mutate fargate coredns pod annotations
  * Ignore unsupported zone types when creating a zone mapping
  * Add missing permission 'deletecollection for pvc' to
    emr-containers role which is needed for Spark Jobs running >=
    emr-6.12
  * Prepare for next development iteration
* Sun Jan  7 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.167.0:
  * Add release notes for 0.167.0
  * add documentation for access entries
  * remove user creation from integration test
  * fix static errors
  * address PR comments
  * add test case for disabled cluster admin permissions
  * Fix dry-run test
  * Fix lint errors
  * only pass necessary fields to access entry action structs
  * change package aliasing
  * parse principalARN as cobra value instead of string
  * Fix error message
  * patch validations
  * fix unit + integration tests
  * delete access entries stacks on cluster deletion + refactor
    integration test
  * update access entries integration test to account for multiple
    use cases
  * refactor get and delete command to check API availability using
    cluster status
  * Remove node policy check
  * Add new utils command to enable access entries API
  * Add support for access entries get and delete commands
  * Fix printers tests
  * Add tests for bootstrapClusterCreatorAdminPermissions
  * Validate access to the Kubernetes API server
  * Refactor unit tests, add more test cases
  * Add unit tests, generate schema
  * Add integration tests for self-managed nodegroups using access
    entries
  * Authorise self-managed nodegroups using access entries
  * Add support for creating access entries
  * Support disabling cluster-admin access for cluster creator
  * Add support for ca-west-1
  * Bump AWS dependencies, fix test
  * Update build image
  * Bump dependencies
  * skip role creation if already existing (#7407)
  * fix info message around used EC2 key pair (#7405)
  * temporarly remove irsav1 cluster deletion (#7383)
  * Prepare for next development iteration
* Fri Dec 15 2023 kastl@b1-systems.de
- Update to version 0.166.0:
  * Add release notes for 0.166
  * Fix typo
  * Skip pod identity migration tests
  * Generate deep copies of IAMStatement
  * Correct documentation example link
  * Add utils command to migrate to pod identity associations
  * (#7343)
  * Update reference for bottlerocket settings (#7375)
  * Disable module caching in actions/setup-go
  * Bump actions/first-interaction from 1.2.0 to 1.3.0
  * Bump docker/metadata-action from 5.0.0 to 5.3.0
  * Fix STS interface
  * Update build image tag and actions
  * Fix `build-integration-test` for pod_identity_associations
  * Prepare for next development iteration
* Wed Nov 29 2023 kastl@b1-systems.de
- Update to version 0.165.0:
  * change file name for release notes
  * Add release notes for 0.165.0 (#7314)
  * Add documentation for pod identity associations feature (#7313)
  * Implement updating and deleting pod identity associations
    (#7315)
  * Ignore google docs domains for link checker
  * Add support for creating and fetching pod identity associations
    (#7312)
  * Bump all aws-sdks
  * Bump aws-sdk dependencies
  * Bump dependencies
  * [CRUD Suite] Delete nodegroups in subnet before the subnet
    itself (#7250)
  * [CRUD Suite] Delete extra subnet before deleting cluster
    (#7248)
  * [CRUD integration] Add wait flag to delete cluster command
    (#7246)
  * Improve CRUD suite runtime (#7208)
  * Fix README Links
  * Bump google.golang.org/grpc from 1.58.2 to 1.58.3
  * Prepare for next development iteration
* Fri Oct 27 2023 kastl@b1-systems.de
- Update to version 0.164.0:
  * Add release notes for 0.164
  * Don't close error channel early when wait flag is used (#7217)
  * Add documentation for `utils update-cluster-vpc-config`
  * Add integration tests for `utils update-cluster-vpc-config`
  * Deprecate commands
  * Add unit tests
  * Generate schema
  * Allow mutating control plane subnets and security groups
  * Add unit tests
  * Generate mocks
  * Add `eksctl utils update-cluster-vpc-config` to update the
    cluster VPC config
  * Prepare for next development iteration
* Tue Oct 24 2023 kastl@b1-systems.de
- Update to version 0.163.0:
  * Release notes for 0.163.0
  * Update dependencies and permissions for stale workflow
  * Update coredns (#7179)
  * Automatically update coredns assets using Github workflows
    (#7178)
  * Add support for P5 instances
  * Bump golang.org/x/net from 0.16.0 to 0.17.0
  * Update build distros workflow to save disk space
  * Update build image
  * Bump dependencies
  * Prepare for next development iteration
* Fri Oct 13 2023 kastl@b1-systems.de
- Update to version 0.162.0:
  * Add release notes for 0.162
  * Fix ELB cleanup failure due to resource name end with a hyphen
    (#7029)
  * Set AWS credential expiry window to 30 minutes (#7116)
  * Fix coredns 1.28 asset
  * Prepare for next development iteration
* Fri Oct  6 2023 kastl@b1-systems.de
- Update to version 0.161.0:
  * Release notes
  * update css and general cleanup
  * clean up and add a better image for cluster demo
  * Added contributors section on homepage
  * fix links in html
  * clean up index.md and fix some img links
  * Clean up styling and updated content
  * Landing page - initial commit
  * Update gomarkdown
  * Upgrade go-restful
  * Make EKS 1.27 default (#7117)
  * Fix `deleteAddonsStacksTasks` generator (#7118)
  * Prepare for next development iteration
  * Move addons related tasks to actions package (#7077)
  * Refine log statements using `%%w` for better formatting and UX
* Fri Sep 29 2023 kastl@b1-systems.de
- Update to version 0.160.0:
  * Release notes for 0.160.0
  * Bump dependencies
  * Add support for EKS 1.28
  * Prepare for next development iteration (#7093)
* Tue Sep 26 2023 kastl@b1-systems.de
- Update to version 0.159.0:
  * Add release notes for 0.159.0 (#7091)
  * updated more actions and deps
  * Update github actions and tidy up
  * Allow managed suite specs to run in parallel (#7065)
  * Fix doc example for bottlerocket bootstrap container
  * Replace deprecated functions, fix lint errors
  * Update to Go 1.20
  * Prepare for next development iteration
- BuildRequire go1.20
* Fri Sep 22 2023 kastl@b1-systems.de
- Update to version 0.158.0:
  * Release notes for 0.158.0
  * Bump `github.com/cloudflare/cfssl` to fix indirect deps DOS
    vulnerability (#7067)
  * Upgrade goproxy to fix DoS vulnerability
  * Call `kubectl version` command with `--output=json` flag
    (#7032)
  * Update README.md
  * Corrected Chocolatey Install Command
  * Prepare for next development iteration
* Fri Sep 15 2023 kastl@b1-systems.de
- Update to version 0.157.0:
  * Release notes for 0.157.0
  * Bump dependencies
  * update readme with new url of logo image
  * fix permission denied error for link checker
  * fix *** missing separator.  Stop. error
  * fix dependencies required for social cards
  * Material version updates and added social cards, cookie consent
    and feedback functionality
  * Fix `update aws node` workflow (#7045)
  * Add note on how to use `--include/exclude` flags when creating
    iamserviceaccounts (#7047)
  * Skip adding egress rules if default egress rule is present
  * Disallow passing a vpc.securityGroup with external SG rules for
    unowned clusters
  * Bump actions/checkout from 3.6.0 to 4.0.0
  * Prepare for next development iteration
* Fri Sep  8 2023 kastl@b1-systems.de
- Update to version 0.156.0:
  * Add release notes for 0.156.0 (#7033)
  * cleanup
  * Added adopters ticker for the docs
  * Cleanup subnets with invalid AZs before importing VPC from CFN
    stack (#6935)
  * Bump aws-actions/configure-aws-credentials from 2.2.0 to 3.0.1
    (#7008)
  * Update build image tag
  * Bump dependencies
  * Prepare for next development iteration
* Wed Sep  6 2023 kastl@b1-systems.de
- Update to version 0.155.0:
  * Add release notes for 0.155
  * Improve unit tests' runtime (#6992)
  * Bump dependencies (#6998)
  * Add support for us-iso-west-1 region
  * Update Ginkgo
  * Replace deprecated Ginkgo CLI options
  * Add validations for managed nodegroup labels (#6947)
  * Fix merge release workflow when there is nothing to merge
  * Set region when config file is not supplied
  * Revert "Set default volume type for ISO regions"
  * Prepare for next development iteration
* Wed Sep  6 2023 kastl@b1-systems.de
- Update to version 0.154.0:
  * Release notes for 0.154.0
  * Bump actions/setup-go from 4.0.1 to 4.1.0
  * Bump aws-actions/amazon-ecr-login from 1.6.2 to 1.7.0
  * Fix error message for Bottlerocket validation
  * Add references to Enterprise support with Flux on Gitops page
    (#6968)
  * Don't wait for aws-efs-csi-driver if cluster has no nodegroups
    (#6960)
  * Bring Windows integration test runtime down to less than half
  * Prepare for next development iteration (#6953)
* Wed Sep  6 2023 kastl@b1-systems.de
- Update to version 0.153.0:
  * Add release notes for 0.153.0 (#6948)
  * Bump dependencies
  * Bump dependencies and Update build image tag
  * Unit test creating the EKS provider (#6875)
  * Update Bottlerocket image version on nodegroup upgrade (#6923)
  * Remove PR rebase workflow (#6934)
  * Allow setting cluster-dns-ip for Bottlerocket
  * Improve error message when `overrideBootstrapCommand` is
    required for `customAMIs` (#6897)
  * Prepare for next development iteration
* Wed Sep  6 2023 kastl@b1-systems.de
- Update to version 0.152.0:
  * Release notes for 0.152.0
  * Bump dependencies
  * Fix PR Rebase workflow (#6903)
  * Replace deprecated field
  * Bump dependencies
  * Update announcement
  * Add support for Tel Aviv (il-central-1)
  * Remove typo
  * Update workflows with pinned sha
  * Remove iam:ListInstanceProfiles from the required permissions
    list (#6898)
  * Bump dependencies
  * Prepare for next development iteration
  * Add option to print specific events when running `eksctl
    describe-stacks` (#6851)
  * Fix k8s.io/kubernetes version
* Sun Aug  6 2023 kastl@b1-systems.de
- Update to version 0.151.0:
  * Add release notes for 0.151
  * Bump dependencies (#6859)
  * Support custom Ubuntu AMIs for EKS-managed nodegroups (#6850)
  * Bump dependencies
  * Fix error with tar in `Post Cache go-build and mod` step
  * Fix setting link-time variables for release version
  * Cleanup Flux Integration (#6836)
  * Removing unused workflow
  * Paginate DescribeInstanceTypeOfferings response (#6832)
  * Add tests for PowerShell utils
  * Support custom AMIs for self-managed Windows nodegroups
  * Select one subnet for AZs where multiple are present and no VPC
    config provided (#6814)
  * Prepare for next development iteration (#6833)
  * go fmt
  * deprecated 1.22
* Thu Jul 20 2023 kastl@b1-systems.de
- Update to version 0.150.0:
  * Bump dependencies (#6830)
  * Update release notes for 0.150 (#6829)
  * Free up disk space in release workflow before building binaries
    (#6827)
  * Remove mockery config from dockerignore (#6828)
  * Update measurement id for GA
  * Bump mockery from 2.30.17 to 2.32.0 (#6819)
  * remove duplicate
  * Release notes for 0.150.0
  * Regenerate mocks
  * Migrate to mockery v2
  * Bundle dependabot updates
  * Updated links with both blog posts
  * Add announcement for transfer to new Github Organisation
  * Bump dependencies (#6803)
  * Add manual push-build-image workflow
  * Update image repository to ECR in workflows
  * Add ECR publish workflow
  * Update description on image repo
  * Prepare for next development iteration
* Thu Jul 13 2023 kastl@b1-systems.de
- Update to version 0.149.0:
  * Fix origin check in release script (#6800)
  * Release notes for 0.149.0
  * Bump dependencies (#6788)
  * Fix AWS_REGION and AWS_DEFAULT_REGION support for eksctl
    commands (#6787)
  * Undo changes to tag-common.sh
  * Update generated files
  * Update current github urls with new org urls
  * Fix generating mocks for aws-sdk-go-v2 interfaces
  * Revert "Support for Inf2 and trn1n instance types"
  * Pin K8s dependencies chain to 1.25 (#6677)
  * Adding Inf2 and trn1n support
  * Prepare for next development iteration
* Sat Jul  8 2023 kastl@b1-systems.de
- Update to version 0.148.0:
  * Add release notes for 0.148
  * Update documentation
  * Replaced weaveworksbot with eksctlbot in workflows and actions
  * Fix S3 endpoint for aws-iso-b
  * Fix Karpenter test
  * Fix support for fully-private clusters for ISO regions
  * Set default volume type for ISO regions
  * Refactor handling of partitions, fix validating partition
  * Fix unit tests
  * Add support for us-iso-east-1 and us-isob-east-1 regions
  * Bump dependencies (#6754)
  * resource should be nil if not found (#6756)
  * Migrate to sdk v2 - configuration loading (#6432)
  * Bump dependencies (#6742)
  * Fix documentation for EKS interface endpoint
  * Added new logo and favicon assets
  * Prepare for next development iteration
* Fri Jun 30 2023 kastl@b1-systems.de
- Update to version 0.147.0:
  * Release notes for 0.147.0
  * add identity action to update-generated workflow
  * Use nodeAffinity to determine if an addon supports ARM64
    (#6695)
  * Bump github.com/aws/aws-sdk-go from 1.44.286 to 1.44.288
  * Prepare for next development iteration (#6703)
  * coredns probes got mixed up for kubernetes 1.26 (#6707)
  * Bump dependencies
  * Update docs with `preserve` option to create addon
* Fri Jun 23 2023 kastl@b1-systems.de
- Update to version 0.146.0:
  * add documentation section in release notes
  * Release notes for 0.146.0
  * Updated slack urls for new k8s slack channel
  * chore: update vpc cni to be compatible with k8s >1.25
  * Bump docker/metadata-action from 4.5.0 to 4.6.0
  * Bump dependencies
  * Prepare for next development iteration
* Fri Jun 16 2023 kastl@b1-systems.de
- Update to version 0.145.0:
  * Add notes for release 0.145.0 (#6678)
  * Bump dependencies (#6674)
  * Added configurable output stream (#6675)
  * 'gofmt'-ed pkg/cfn/builder/statement.go
  * Updated wellKnownPolicy for Cluster Autoscaler and LoadBalancer
    Controller
  * Prepare for next development iteration
  * Update release notes
  * remove snap installation
  * cleanup of readme and contributing docs, fixed formatting and
    typos
* Mon Jun 12 2023 kastl@b1-systems.de
- Update to version 0.144.0:
  * Add release notes for 0.144
  * Add integration tests for resource-based hostnames (#6659)
  * Only retry appropriate errors (#6645)
  * Excluding email from link checker
  * Allow creating subnets with resource-based hostnames (#6651)
  * Added manual changes
  * Updated IAM policy statement for loadbalancer controller
  * Bump github.com/aws/aws-sdk-go from 1.44.268 to 1.44.271
  * Fix logging stack events logic (#6649)
  * Generated ATTRIBUTIONS.md file
  * Set default Windows volume name to /dev/sda1 (#6638)
  * Upgraded schemer from v0.0.0-2021 to v0.0.0-2023
  * Upgrade sourcegraph/go-diff from 0.6.2 to 0.7.1
  * Updated bufpipe dependency from 1.0.3 to 1.0.4
  * Prepare for next development iteration
  * port Add ready plugin to CoreDNS and use health.lameduck for a
    safer shutdown to 1.27
  * port Add ready plugin to CoreDNS and use health.lameduck for a
    safer shutdown to 1.25 and 1.26
  * port Add ready plugin to CoreDNS and use health.lameduck for a
    safer shutdown to 1.25 and 1.26
  * Use `%%w` verb for errors
  * address code review suggestions
  * fix to clean up ALB security groups
  * fix to clean up ALBs using IngressClassName
* Sat May 27 2023 kastl@b1-systems.de
- Update to version 0.143.0:
  * updated some dependencies
  * Release 0.143.0
  * Add support for EKS 1.27 (#6639)
  * Revert "Revert defaulting to IMDSv2  (#6624)" (#6631)
  * Fix readiness probe in HTTP test (#6628)
  * Added Amine and YuXiang to coreteam
  * Prepare for next development iteration (#6626)
* Wed May 24 2023 kastl@b1-systems.de
- Update to version 0.142.0:
  * Add release notes for 0.142.0 (#6623)
  * Revert defaulting to IMDSv2  (#6624)
  * Fix CRUD and Managed integration tests (#6622)
  * Update config file examples to reflect amiFamily is required
    with custom AMI (#6617)
  * Update integration tests and userdocs references to IMDSv1
    (#6618)
  * Make IMDSv2 the default (#6612)
  * update sts.go
  * Update build image manifest, tag file and workflows
  * updated dependencies
  * Add TagResource perm to EFS wellknown policy
  * Revert "Adding support for inf2 and trn1n instances"
  * Bump dependencies
  * Prepare for next development iteration
  * Adding support for inf2 and trn1n instances
* Fri May 12 2023 kastl@b1-systems.de
- Update to version 0.141.0:
  * release notes for 0.141.0
  * Update vpc-configuration.md (#6569)
  * Prepare for next development iteration
* Fri May  5 2023 kastl@b1-systems.de
- Update to version 0.140.0:
  * Add release notes for 0.140.0 (#6560)
  * Only select AZs that support all instance types on nodegroup
    creation (#6464)
  * Update schema.json
  * updated deps and schema
  * Force kubeconfig get-token output format to json
  * Revert "Temporarily remove failing Bottlerocket upgrade test
    (#6540)"
  * Bump lycheeverse/lychee-action from 1.6.1 to 1.7.0
  * Prepare for next development iteration
* Fri Apr 28 2023 kastl@b1-systems.de
- Update to version 0.139.0:
  * Release notes for 0.139.0
  * Security Policy for eksctl project
  * Temporarily remove failing Bottlerocket upgrade test (#6540)
  * Update userdocs/src/usage/eks-private-cluster.md
  * Bump golang.org/x/crypto from 0.7.0 to 0.8.0
  * fix flux version validation
  * Improve installation instructions
  * Prepare for next development iteration
  * Fix nesting of info text
  * Added EKS interface endpoint support to eks-private-cluster.md
* Fri Apr 21 2023 kastl@b1-systems.de
- Update to version 0.138.0:
  * Add release notes for 0.138
  * Bump dependencies (#6525)
  * Add support for EKS 1.26 (#6502)
  * Add volcano podgroups permissions (#6500)
  * Prepare for next development iteration
* Thu Apr 13 2023 kastl@b1-systems.de
- Update to version 0.137.0:
  * Add release notes for 0.137.0 (#6496)
  * Fix crud int test (#6497)
  * Add scale nodegroup integration test with wait flag and fix old
    flakes (#6495)
  * Add wait flag to `scale nodegroup` (#6406)
  * Add support for Spot Interruption Queue within Karpenter
    (#6460)
  * Bump github.com/docker/docker
  * added two more domains to ignore for link checker
  * Update build image manifest, tag file and workflows
  * Update userdocs/src/usage/eksctl-karpenter.md
  * Update eksctl-karpenter.md
  * Prepare for next development iteration
* Mon Apr  3 2023 kastl@b1-systems.de
- Update to version 0.136.0:
  * removed the Karpenter PR since it'll be reverted
  * Release 0.136.0
  * Revert "Update Karpenter CFN template to support Spot
    Interruption Queue (#6453)" (#6457)
  * Update Karpenter CFN template to support Spot Interruption
    Queue (#6453)
  * Fix panic when a nodegroup element is not set in ClusterConfig
    (#6443)
  * Log stack events on integration test failure (#6450)
  * Update actions and deps
  * Prepare for next development iteration
* Fri Mar 24 2023 kastl@b1-systems.de
- Update to version 0.135.0:
  * Add release notes for 0.135.0 (#6439)
  * Update addon example with ebs addon (#6438)
  * [Upgrade nodegroup via EKS API] Make AMI release version
    customisable (#6340)
  * Add m7g and r7g as ARM instance types (#6436)
  * deps update + updated outposts page
  * Handle deprecated AMIs when scaling self-managed nodegroups
  * Fix a typo in an error message (#6431)
  * Bump dependencies
  * Prepare for next development iteration
  * Update userdocs/src/usage/cloudwatch-cluster-logging.md
  * Update userdocs/src/usage/cloudwatch-cluster-logging.md
  * Update userdocs/src/usage/cloudwatch-cluster-logging.md
  * update: cloudwatch log descriptions
* Fri Mar 17 2023 kastl@b1-systems.de
- Update to version 0.134.0:
  * Add new region to docs
  * Add release notes for 0.134.0
  * Add support for Melbourne (ap-southeast-4)
  * Fix cluster argument in addons integration tests (#6397)
  * reworded the KMS encryption page with more upto date info and
    avoid broken link
  * make EKS 1.25 default
  * Add integration tests for addons in a cluster with no nodes
    (#6378)
  * Update build image manifest, tag file and workflows
  * Improve messages during creation of iamserviceaccount (#5856)
  * fix the image in coredns asset
  * Add condition to restrict fargate pod execution role to source
    arn (#6375)
  * Prepare for next development iteration (#6380)
* Fri Mar 10 2023 kastl@b1-systems.de
- Update to version 0.133.0:
  * Release notes for 0.133.0
  * [Upgrade nodegroup via EKS API] Don't specify kubernetes
    version when using a custom AMI (#6318)
  * Bump github.com/aws/aws-sdk-go from 1.44.209 to 1.44.210
    (#6370)
  * Bump lycheeverse/lychee-action from 1.5.4 to 1.6.1 (#6361)
  * Improve bottlerocket integration tests - custom AMI and GPU
    support (#6347)
  * Bump dependencies
  * Use addons published by AWS EKS for describe-addon-versions
  * Prepare for next development iteration (#6339)
* Sun Mar  5 2023 Johannes Kastl <kastl@b1-systems.de>
- new package eksctl: The official CLI for Amazon EKS
